Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(140)

Unified Diff: chromeos/dbus/shill_manager_client.h

Issue 10915106: Renaming instances of "flimflam" with "shill", now that we're only (Closed) Base URL: http://git.chromium.org/chromium/src.git@master
Patch Set: Upload after merge Created 8 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chromeos/dbus/shill_ipconfig_client_unittest.cc ('k') | chromeos/dbus/shill_manager_client.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chromeos/dbus/shill_manager_client.h
diff --git a/chromeos/dbus/flimflam_manager_client.h b/chromeos/dbus/shill_manager_client.h
similarity index 81%
rename from chromeos/dbus/flimflam_manager_client.h
rename to chromeos/dbus/shill_manager_client.h
index 98cb9cfd4b36259e5c5c8c657489da9864378f8e..cc2117498af5158838e8952d8c274a58f66b6392 100644
--- a/chromeos/dbus/flimflam_manager_client.h
+++ b/chromeos/dbus/shill_manager_client.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROMEOS_DBUS_FLIMFLAM_MANAGER_CLIENT_H_
-#define CHROMEOS_DBUS_FLIMFLAM_MANAGER_CLIENT_H_
+#ifndef CHROMEOS_DBUS_SHILL_MANAGER_CLIENT_H_
+#define CHROMEOS_DBUS_SHILL_MANAGER_CLIENT_H_
#include <string>
@@ -11,7 +11,7 @@
#include "base/callback.h"
#include "chromeos/chromeos_export.h"
#include "chromeos/dbus/dbus_client_implementation_type.h"
-#include "chromeos/dbus/flimflam_client_helper.h"
+#include "chromeos/dbus/shill_client_helper.h"
namespace dbus {
@@ -21,19 +21,19 @@ class Bus;
namespace chromeos {
// FlimflamManagerClient is used to communicate with the Flimflam Manager
// service. All methods should be called from the origin thread which
// initializes the DBusThreadManager instance.
-class CHROMEOS_EXPORT FlimflamManagerClient {
+class CHROMEOS_EXPORT ShillManagerClient {
public:
- typedef FlimflamClientHelper::PropertyChangedHandler PropertyChangedHandler;
- typedef FlimflamClientHelper::DictionaryValueCallback DictionaryValueCallback;
+ typedef ShillClientHelper::PropertyChangedHandler PropertyChangedHandler;
+ typedef ShillClientHelper::DictionaryValueCallback DictionaryValueCallback;
- virtual ~FlimflamManagerClient();
+ virtual ~ShillManagerClient();
// Factory function, creates a new instance which is owned by the caller.
// For normal usage, access the singleton via DBusThreadManager::Get().
- static FlimflamManagerClient* Create(DBusClientImplementationType type,
+ static ShillManagerClient* Create(DBusClientImplementationType type,
dbus::Bus* bus);
// Sets PropertyChanged signal handler.
@@ -88,12 +88,12 @@ class CHROMEOS_EXPORT FlimflamManagerClient {
protected:
// Create() should be used instead.
- FlimflamManagerClient();
+ ShillManagerClient();
private:
- DISALLOW_COPY_AND_ASSIGN(FlimflamManagerClient);
+ DISALLOW_COPY_AND_ASSIGN(ShillManagerClient);
};
} // namespace chromeos
-#endif // CHROMEOS_DBUS_FLIMFLAM_MANAGER_CLIENT_H_
+#endif // CHROMEOS_DBUS_SHILL_MANAGER_CLIENT_H_
« no previous file with comments | « chromeos/dbus/shill_ipconfig_client_unittest.cc ('k') | chromeos/dbus/shill_manager_client.cc » ('j') | no next file with comments »

Powered by Google App Engine
@@ -21,19 +21,19 @@ class Bus;
namespace chromeos {
-// FlimflamManagerClient is used to communicate with the Flimflam Manager
+// ShillManagerClient is used to communicate with the Shill Manager
// service. All methods should be called from the origin thread which
// initializes the DBusThreadManager instance.
This is Rietveld 408576698